package es.rickyepoderi.bootablejar.rest;

import io.swagger.v3.jaxrs2.integration.JaxrsOpenApiContextBuilder;
import io.swagger.v3.jaxrs2.integration.resources.OpenApiResource;
import io.swagger.v3.oas.integration.OpenApiConfigurationException;
import io.swagger.v3.oas.integration.SwaggerConfiguration;
import io.swagger.v3.oas.models.OpenAPI;
import io.swagger.v3.oas.models.info.Info;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import javax.servlet.ServletConfig;
import javax.ws.rs.ApplicationPath;
import javax.ws.rs.core.Application;
import javax.ws.rs.core.Context;

/**
 *
 * @author rmartinc
 */
@ApplicationPath("api")
public class RestApplication extends Application {

    @Context
    private ServletConfig servletConfig;
    
    public RestApplication() {
        try {
            new JaxrsOpenApiContextBuilder()
                    .servletConfig(servletConfig)
                    .application(this)
                    .openApiConfiguration(new SwaggerConfiguration()
                            .openAPI(new OpenAPI()
                                    .info(new Info()
                                            .title("Hello App")
                                            .description("Sample Bootable JAR Hello App")
                                            .version("0.0.1-SNAPSHOT")))
                            .prettyPrint(true)
                            .resourcePackages(Collections.singleton(HelloEndpoint.class.getPackage().getName())))
                    .buildContext(true);
        } catch (OpenApiConfigurationException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public Set<Class<?>> getClasses() {
        Set<Class<?>> classes = new HashSet<>();
        classes.add(HelloEndpoint.class);
        classes.add(OpenApiResource.class);
        // don't add the filter if using EJB security
        classes.add(RolesAuthorizationFilter.class);
        return classes;
    }
}
